Documentation
¶
Index ¶
Constants ¶
const ( TCP = "tcp" UDP = "udp" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Graphite ¶
type Graphite struct {
// contains filtered or unexported fields
}
func NewGraphite ¶
create a new Graphite struct and connect to the underlying connection. If the connection isn't immediately successful, we timeout, we sleep, and we retry. if we are underbale to connect after 5 attempts, we panic.
func (*Graphite) SendStruct ¶
func (g *Graphite) SendStruct(obj interface{})
Transform a struct into an array of metrics and send them to graphite/
Click to show internal directories.
Click to hide internal directories.